// var projserv = require('./services');
// var angular = require('../lib/angular.min');
// var ngRoute = require('../lib/angular-route.min');
// var ngSanitize = require('../lib/angular-sanitize.min');

// var angular = require('angular').angular;


var gsapp = angular.module('project', ['project.service', 'app.directives', 'ngRoute', 'ngSanitize', 'ngResource', 'ngTouch']);

gsapp.config(function ($routeProvider) {
	$routeProvider
		.when('/', {
			controller: 'viewOptions',
			templateUrl: 'partials/top.html'
		})
		.when('/teams/:team/:tournID/', {
			controller: 'teamDisplay',
			templateUrl: 'partials/team.html'
		})
		.when('/teams/:team/:tournID/:tournName/', {
			controller: 'teamDisplay',
			templateUrl: 'partials/team.html'
		})
		.when('/tournaments/:filter/', {
			controller: 'tournDisplay',
			templateUrl: 'partials/tournaments.html'
		})
		.when('/tournaments/:filter/:tournament/', {
			controller: 'resultDisplay',
			templateUrl: 'partials/tournament.html'
		})
		.when('/tournaments/:filter/:tournament/:tournName/', {
			controller: 'resultDisplay',
			templateUrl: 'partials/tournament.html'
		})
		.when('/player/:player/:tournament/:tournName/', {
			controller: 'individualDisplay',
			templateUrl: 'partials/player.html'
		})
		.when('/players/:filter/:tournament/:tournName/', {
			controller: 'playerDisplay',
			templateUrl: 'partials/players_tourn.html'
		})

	// TESTING TEMPLATES

	.when('/test/teams/:team/:tournID/', {
		controller: 'teamDisplay',
		templateUrl: 'partials/teamnew.html'
	})
		.when('/test/tournaments/:filter/:tournament/:tournName/', {
			controller: 'resultDisplay',
			templateUrl: 'partials/tournamentnew.html'
		})
		.when('/test/players/:filter/:tournament/:tournName/', {
			controller: 'playerDisplay',
			templateUrl: 'partials/players_tournnew.html'
		})

	// Default redirect

	.otherwise({
		redirectTo: '/'
	});
});


gsapp.filter('firstNine', function () {
	return function (items) {
		var holes = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
		angular.forEach(items, function (item) {
			if (item.HOLE < 10) {
				this[item.HOLE] = item;
			}
		}, holes);
		// Go through the available data and put it back into an array with 9 slots then remove any not needed.
		holes.shift();
		return holes;
	};
});

gsapp.filter('backNine', function () {
	return function (items) {
		var holes = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18];
		angular.forEach(items, function (item) {
			if (item.HOLE > 9) {
				this[item.HOLE] = item;
			}
		}, holes);
		holes = holes.slice(10);
		return holes;
	};
});

// provides the numbers up to range to fill an array
gsapp.filter('range', function () {
	return function (val, range) {
		range = parseInt(range);
		for (var i = 0; i < range; i++) {
			val.push(i);
		}
		return val;
	};
});

// sets and provides the title
gsapp.factory('titler', function () {
	var title = '';
	var base = 'Golfstat';
	return {
		title: function () {
			if (title === '')
				return base;
			return title + ' - ' + base;
		},
		setTitle: function (newTitle) {
			title = newTitle;
		}
	};
});

// provides functions to do the silly golf scoring conventions
gsapp.factory('sillyGolf', function () {
	return {
		// returns E when par is 0
		even: function (par) {
			par = par > 0 ? '+' + par : par;
			return par === 0 ? 'E' : par;
		},
		// returns F when the hole completed is 18
		thru: function (hole) {
			return hole === 18 ? 'F' : hole;
		},
		// returns a string of thru values for the min and max completed holes completed
		thruTeam: function (team) {
			return (this.thru(team.MIN_THRU) === 'F' && this.thru(team.MAX_THRU) === 'F') ?
				'F' : this.thru(team.MIN_THRU) + '-' + this.thru(team.MAX_THRU);
		},
		// returns '-' till the player is done with a round
		totalPar: function (hole, par) {
			return par; // go ahead and show the par according to Nick
			//return this.thru(hole) === 'F' ? par : '-';
		},
		// returns '-' till the player is done with a round then the score
		totalScr: function (hole, scr) {
			return scr; // go ahead and show the score according to Nick
			//return this.thru(hole) === 'F' ? scr : '-';
		},
		totScr: function (team) {
			if (team.FINISHED_CD == 'Y') {
				return team.TOURNAMENT_TOTAL_TEAM_SCORE;
			} else {
				var rnd = parseInt(team.ROUND_ID) - 1;
				var score = 0;
				while (rnd > 0) {
					score = score + parseInt(team['ROUND' + rnd + '_TOTAL']);
					rnd = rnd - 1;
				}
				return score;
			}
		},
		totScrPlyr: function (player) {
			if (player.FINISHED == 'Y') {
				return player.TOTAL_PLAYER_SCORE_SUMMARY;
			} else {
				var rnd = parseInt(player.ROUND_ID) - 1;
				var score = 0;
				while (rnd > 0) {
					score = score + parseInt(player['ROUND' + rnd + '_TOTAL']);
					rnd = rnd - 1;
				}
				return score;
			}
		}
	};
});

gsapp.config(function ($httpProvider) {
	delete $httpProvider.defaults.headers.common['X-Requested-With'];
});


gsapp.factory('statData', ['$resource',
  function ($resource) {

		var gsurl = 'http://www.golfstatresults.com/webservices/sec/event.cfc';

		function fixTheD(data) {

			var container = [];

			angular.forEach(data.DATA, function (value, key) {
				var thing = {};
				angular.forEach(value, function (val, key) {
					if (data.COLUMNS[key] === 'START_DATE' || data.COLUMNS[key] === 'END_DATE') {
						var d = new Date(val);
						this[data.COLUMNS[key]] = d.getTime();
					} else {
						this[data.COLUMNS[key]] = val;
					}
				}, thing);
				// Apparently this is faster than using the push method
				this[this.length] = thing;
			}, container);
			return container;
		}

		var Golfstat = $resource(gsurl, {
			'UID': 'golfweek',
			'PWD': 'gsgw13',
			'returnFormat': 'JSON'
		}, {
			tournaments: {
				url: gsurl + '?date1=:date1&date2=:date2',
				method: 'GET',
				params: {
					method: 'getTournaments'
				},
				isArray: true,
				transformResponse: function (data) {
					return fixTheD(angular.fromJson(data));
				}
			},
			teams: {
				url: gsurl + '?tt_id=:teamID&tournament_id=:tournID',
				method: 'GET',
				params: {
					method: 'getTournamentTeams'
				},
				isArray: true,
				transformResponse: function (data) {
					return fixTheD(angular.fromJson(data));
				}
			},
			players: {
				url: gsurl + '?tt_id=:teamID&tournament_id=:tournID',
				method: 'GET',
				params: {
					method: 'getTournamentPlayers'
				},
				isArray: true,
				transformResponse: function (data) {
					return fixTheD(angular.fromJson(data));
				}
			},
			teamScores: {
				url: gsurl + '?rd=:roundID&tournament_id=:tournID',
				method: 'GET',
				params: {
					method: 'teamLB'
				},
				isArray: true,
				transformResponse: function (data) {
					return fixTheD(angular.fromJson(data));
				}
			},
			playerScores: {
				url: gsurl + '?rd=:roundID&tournament_id=:tournID',
				method: 'GET',
				params: {
					method: 'playerLB'
				},
				isArray: true,
				transformResponse: function (data) {
					return fixTheD(angular.fromJson(data));
				}
			},
			finalPlace: {
				url: gsurl + '?rd=:roundID&tournament_id=:tournID',
				method: 'GET',
				params: {
					method: 'playerLB'
				},
				isArray: true,
				transformResponse: function (data) {
					return data.DATA[0][2];
					// return fixTheD(angular.fromJson(data));
				}
			}
		});

		return Golfstat;

  }
]);

(function (angular) {

	var directives = angular.module('app.directives', []);

	directives.directive('backButton', function () {
		return {
			restrict: 'E',
			template: "<button class='back-button'><span>back</span></button>",
			scope: {
				back: '@back'
			},
			link: function (scope, element, attrs) {
				element.bind('click', function () {
					history.back();
					scope.$apply();
				});
			}
		};
	});

	directives.directive('reloadButton', ["$route", "$interval",
		function ($route, $interval) {
			return {
				restrict: 'E',
				template: "<button class='reload-button'></button>",
				link: function (scope, element, attrs) {
					element.bind('click', function () {
						$route.reload();
						scope.$apply();
					});
					var interval = (attrs.timer) ? parseInt(attrs.timer) : 120000;
					var rel = $interval(function () {

						// console.log($route.current);
						$route.reload();
					}, interval);
					scope.$on('$routeChangeStart', function (e) {
						$interval.cancel(rel);
					});
				}
			};
      }]);

	directives.directive('topBar', function () {
		return {
			restrict: 'E',
			transclude: true,
			templateUrl: 'partials/header.html'
		};
	});

	directives.directive('bottomBar', function () {
		return {
			restrict: 'E',
			transclude: true,
			templateUrl: 'partials/footer.html'
		};
	});

	directives.directive('repeatDone', function () {
		return function (scope, element, attrs) {
			if (scope.$last) {
				scope.$eval(attrs.repeatDone);
			}
		};
	});

	directives.directive('dataLoad', function () {
		return {
			restrict: 'E',
			link: function (scope, element, attrs) {

				var img = document.createElement('img');
				img.src = 'img/ajax-loader.gif';

				if (element[0].nodeType === 8) {
					element.replaceWith(img);
				} else {
					element[0].appendChild(img);
				}
			}
		};
	});

	directives.directive('backImg', function () {
		return function (scope, element, attrs) {
			attrs.$observe('backImg', function (value) {
				element.css({
					'background-image': 'url(' + value + ')'
				});
			});
		};
	});


	directives.directive('playerData', function ($http, $timeout, $q) {

		var gsurl = 'http://www.golfstatresults.com/webservices/sec/event.cfc';

		var fixTheD = function (data) {
			var container = [];
			angular.forEach(data['DATA'], function (value) {
				var thing = {};
				angular.forEach(value, function (val, key) {
					if (data['COLUMNS'][key] === 'START_DATE' || data['COLUMNS'][key] === 'END_DATE') {
						var d = new Date(val);
						this[data['COLUMNS'][key]] = d.getTime();
					} else {
						this[data['COLUMNS'][key]] = val;
					}
				}, thing);
				// Apparently this is faster than using the push method
				this[this.length] = thing;
			}, container);
			return container;
		}

		return {
			restrict: 'A',
			templateUrl: 'partials/team_player.html',
			scope: {
				playerid: '@',
				topar: '=',
				totals: '=',
				shotcaller: '=',
				shotstart: '=',
				teamscores: '='
			},
			link: function (scope, element, attrs) {

				scope.rounds = [];
				attrs.$observe('playerid', function (val) {
					var params = {
						'method': 'playerDetail',
						'UID': 'golfweek',
						'PWD': 'gsgw13',
						'returnFormat': 'JSON'
					};
					params.pc_id = val;
					params.tournament_id = attrs.tournid;
					var counter = attrs.rnd;

					while (counter > 0) {
						$http.get(gsurl + '?rd=' + counter, {
							params: params,
							transformResponse: function (data) {
								data = angular.fromJson(data);
								return fixTheD(data);
							}
						})
							.success(function (data) {
								if (data.length > 0) {
									scope.rounds.push(data);
									scope.rounds.sort(function (a, b) {
										if (a[0].ROUND_ID > b[0].ROUND_ID) {
											return 1;
										}
										if (a[0].ROUND_ID < b[0].ROUND_ID) {
											return -1;
										}
										return 0;
									});
									//scope.rounds.reverse();
								}
							});

						counter = counter - 1;

					}

				});

				scope.tab = 1;

				scope.tabclick = function (tab) {
					scope.tab = tab;
				}

				$timeout(function () {
					scope.tab = scope.rounds.length;
					console.log(scope.teamscores);
					console.log(scope.rounds);
				}, 2000);


			}
		};
	});


	directives.directive('adImg', ['$q', '$window',
		function ($q, $window) {

			function newWindow(element) {
				var cover = document.createElement('div');
				cover.style.height = '50px';
				cover.style.width = $window.innerWidth + 'px';
				cover.style.bottom = '0';
				cover.style.position = 'absolute';

				var el = document.getElementById(element.parentElement.id);
				el.insertBefore(cover, el.children[0]);

				(function () {
					var el = document.getElementById(element.parentElement.id);
					el.addEventListener('click',
						function () {
                            var href = document.getElementsByTagName('iframe')[0].contentDocument.getElementsByTagName('a')[0].getAttribute('href');
							var ref = window.open(href, '_blank', 'location=no,toolbar=yes'); // use self on android blank on ios
							function closeRef(e) {
								ref.close();
								ref.removeEventListener('exit', function () {
									ref.close();
								});
							}

							ref.addEventListener('exit', closeRef);
						}, false);
				})();
			}

			return function (scope, element, attrs) {
                $window.googletag.cmd.push(function () {
                    $window.googletag.display('mainAd');
                });
                newWindow(element[0]);
			};
      }]);

})(angular);


var googletag = googletag || {};
	googletag.cmd = googletag.cmd || [];
	(function () {
		var gads = document.createElement('script');
		gads.async = true;
		gads.type = 'text/javascript';
		var useSSL = 'https:' == document.location.protocol;
		gads.src = (useSSL ? 'https:' : 'http:') +
			'//www.googletagservices.com/tag/js/gpt.js';
		var node = document.getElementsByTagName('script')[0];
		node.parentNode.insertBefore(gads, node);
	})();


// creates the google analytics object
(function (i, s, o, g, r, a, m) {
	i['GoogleAnalyticsObject'] = r;
	i[r] = i[r] || function () {
		(i[r].q = i[r].q || []).push(arguments)
	}, i[r].l = 1 * new Date();
	a = s.createElement(o),
	m = s.getElementsByTagName(o)[0];
	a.async = 1;
	a.src = g;
	m.parentNode.insertBefore(a, m)
})(window, document, 'script', '//www.google-analytics.com/analytics.js', 'ga');

ga('create', 'UA-565433-30', 'golfweek.com');
